@@ -65,6 +65,9 @@ epoxy_egl_version(EGLDisplay dpy)
     int ret;
 
     version_string = eglQueryString(dpy, EGL_VERSION);
+    if (!version_string)
+        return 0;
+
     ret = sscanf(version_string, "%d.%d", &major, &minor);
     assert(ret == 2);
     return major * 10 + minor;
@@ -97,6 +100,8 @@ epoxy_has_egl_extension(EGLDisplay dpy, const char *ext)
  * @brief Checks whether EGL is available.
  *
  * @return `true` if EGL is available
+ *
+ * @newin{1,4}
  */
 bool
 epoxy_has_egl(void)
